@@ -1,6 +1,9 @@
 from decouple import config
 
 JWT_SECRET = config("JWT_SECRET")
+GOOGLE_CLIENT_ID = config("GOOGLE_CLIENT_ID")
+GOOGLE_CLIENT_SECRET = config("GOOGLE_CLIENT_SECRET")
+REDIRECT_URL = config("REDIRECT_URL")
 MAIL_USERNAME =config('MAIL_USERNAME')
 MAIL_PASSWORD =config('MAIL_PASSWORD')
 MAIL_FROM =config('MAIL_FROM')
